// COTW: Ghost Windows
// Autor: Julio Gorg, a.k.a. Zaelsius
// Web:	www.zsgames.tk


// Para poder utilizar las funciones especiales de Windows 2000, XP y superiores
// es necesario incluir este #define
#define _WIN32_WINNT 0x0500
#include <windows.h>
#include "resource.h"

#define CLASS_NAME "GhostWindowClass"

// Variables globales:
HINSTANCE	hInst;						// Instancia actual
int			iAlpha = 0;					// Opacidad(Factor alfa) de la ventana.
										// De 0(invisible) a 255(totalmente opaca).
int			iInc = 5;					// Incremento de alpha

// Declaraciones de funciones
ATOM				MyRegisterClass(HINSTANCE hInstance);
BOOL				InitInstance(HINSTANCE, int);
LRESULT CALLBACK	WndProc(HWND, UINT, WPARAM, LPARAM);

// WinMain
int APIENTRY WinMain(HINSTANCE hInstance,
                     HINSTANCE hPrevInstance,
                     LPTSTR    lpCmdLine,
                     int       nCmdShow)
{
 	MyRegisterClass(hInstance);

	if (!InitInstance (hInstance, nCmdShow)) 
	{
		return FALSE;
	}
	
	// Bucle de mensajes
	MSG msg;
	while (GetMessage(&msg, NULL, 0, 0)) 
	{
		TranslateMessage(&msg);
		DispatchMessage(&msg);
	}

	return (int) msg.wParam;
}

// MyRegisterClass()

ATOM MyRegisterClass(HINSTANCE hInstance)
{
	WNDCLASSEX wcex;

	wcex.cbSize = sizeof(WNDCLASSEX); 

	wcex.style			= CS_HREDRAW | CS_VREDRAW;
	wcex.lpfnWndProc	= (WNDPROC)WndProc;
	wcex.cbClsExtra		= 0;
	wcex.cbWndExtra		= 0;
	wcex.hInstance		= hInstance;
	wcex.hIcon			= LoadIcon(hInstance, (LPCTSTR)IDI_GHOST);
	wcex.hCursor		= LoadCursor(NULL, IDC_ARROW);
	wcex.hbrBackground	= (HBRUSH)(COLOR_WINDOW+1);
	wcex.lpszMenuName	= 0;
	wcex.lpszClassName	= CLASS_NAME;
	wcex.hIconSm		= LoadIcon(wcex.hInstance, (LPCTSTR)IDI_SMALL);

	return RegisterClassEx(&wcex);
}

// InitInstance(HANDLE, int)

BOOL InitInstance(HINSTANCE hInstance, int nCmdShow)
{
   HWND hWnd;

   hInst = hInstance; // Almacenar identificador de instancia en una variable global

   hWnd = CreateWindow(CLASS_NAME, "COTW: Ghost Windows", WS_OVERLAPPEDWINDOW,
      CW_USEDEFAULT, 0, CW_USEDEFAULT, 0, NULL, NULL, hInstance, NULL);

   if (!hWnd)
   {
      return FALSE;
   }

   // Activamos el flag de estilo WS_EX_LAYERED, necesario para activar las 
   // transparencias. Las ventanas que posean este flag consumen ms recursos, as
   // que es recomendable desactivarlo cuando no estemos utilizando la transparencia.
   SetWindowLong(hWnd,GWL_EXSTYLE,WS_EX_LAYERED);
   ShowWindow(hWnd, nCmdShow);
   UpdateWindow(hWnd);

   // Activamos el temporizador n1, que envia un mensaje WM_TIMER 
   // a nuestra ventana cada 20 milisegundos.
   SetTimer(hWnd,1,20,0);

   return TRUE;
}

//  FUNCIN: WndProc(HWND, unsigned, WORD, LONG)

LRESULT CALLBACK WndProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
{
	int wmId, wmEvent;
	PAINTSTRUCT ps;
	HDC hdc;

	// Procesar los mensajes
	switch (message) 
	{
	// Mensaje del temporizador
	case WM_TIMER:
		// Incrementamos o decrementamos el factor alfa de la ventana
		iAlpha+=iInc;
		SetLayeredWindowAttributes(hWnd,0,iAlpha,LWA_ALPHA);
        if(iAlpha>=255)
			iInc = -5;
		else if(iAlpha<=0)
			iInc = 5;
		break;
	case WM_PAINT:
		hdc = BeginPaint(hWnd, &ps);
		// ..cdigo adicional de pintado aqu
		EndPaint(hWnd, &ps);
		break;
	case WM_DESTROY:
		PostQuitMessage(0);
		break;
	default:
		return DefWindowProc(hWnd, message, wParam, lParam);
	}
	return 0;
}
